**Example 1: 拒绝对等连接请求**



Input: 

```
tccli vpc RejectVpcPeeringConnection --cli-unfold-argument  \
    --PeeringConnectionId pcx-aw8hzt6c
```

Output: 
```
{
    "Response": {
        "RequestId": "e4008f6c-4bd9-42a7-9e6f-83043db431b2"
    }
}
```

